@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -148,16 +148,18 @@ class Customers extends ApiCommand implements ResourceEntity
 	public function listingCount()
 	{
 		if ($this->isAdmin()) {
+			$query_fields = [];
 			$result_stmt = Database::prepare("
 				SELECT COUNT(*) as num_customers
-				FROM `" . TABLE_PANEL_CUSTOMERS . "`
-				WHERE " . ($this->getUserDetail('customers_see_all') ? "1" : " `adminid` = :adminid "));
+				FROM `" . TABLE_PANEL_CUSTOMERS . "` `c`, `" . TABLE_PANEL_ADMINS . "` `a`
+				WHERE `c`.`adminid` = `a`.`adminid` AND " . ($this->getUserDetail('customers_see_all') ? "1" : " `c`.`adminid` = :adminid ") . $this->getSearchWhere($query_fields, true));
 			$params = [];
 			if ($this->getUserDetail('customers_see_all') == '0') {
 				$params = [
 					'adminid' => $this->getUserDetail('adminid')
 				];
 			}
+			$params = array_merge($params, $query_fields);
 			$result = Database::pexecute_first($result_stmt, $params, true, true);
 			if ($result) {
 				return $this->response($result['num_customers']);
@@ -197,6 +199,8 @@ class Customers extends ApiCommand implements ResourceEntity
 	 *                             optional, allow login via webui, if false ONLY the login via webui is disallowed; default true
 	 * @param bool $api_allowed
 	 *                             optional, default is true if system setting api.enabled is true, else false
+	 * @param bool $shell_allowed
+	 *                             optional, default is true if system setting system.allow_customer_shell is true, else false
 	 * @param int $gender
 	 *                             optional, 0 = no-gender, 1 = male, 2 = female
 	 * @param string $custom_notes
@@ -303,6 +307,7 @@ class Customers extends ApiCommand implements ResourceEntity
 				$def_language = $this->getParam('def_language', true, Settings::Get('panel.standardlanguage'));
 				$gui_access = $this->getBoolParam('gui_access', true, 1);
 				$api_allowed = $this->getBoolParam('api_allowed', true, (Settings::Get('api.enabled') && Settings::Get('api.customer_default')));
+				$shell_allowed = $this->getBoolParam('shell_allowed', true, intval(Settings::Get('system.allow_customer_shell')));
 				$gender = (int)$this->getParam('gender', true, 0);
 				$custom_notes = $this->getParam('custom_notes', true, '');
 				$custom_notes_show = $this->getBoolParam('custom_notes_show', true, 0);
@@ -558,6 +563,7 @@ class Customers extends ApiCommand implements ResourceEntity
 						'lang' => $def_language,
 						'gui_access' => $gui_access,
 						'api_allowed' => $api_allowed,
+						'shell_allowed' => $shell_allowed,
 						'docroot' => $documentroot,
 						'guid' => $guid,
 						'diskspace' => $diskspace,
@@ -601,6 +607,7 @@ class Customers extends ApiCommand implements ResourceEntity
 						`def_language` = :lang,
 						`gui_access` = :gui_access,
 						`api_allowed` = :api_allowed,
+						`shell_allowed` = :shell_allowed,
 						`documentroot` = :docroot,
 						`guid` = :guid,
 						`diskspace` = :diskspace,
@@ -1008,12 +1015,14 @@ class Customers extends ApiCommand implements ResourceEntity
 	 * @param int $customernumber
 	 *                             optional
 	 * @param string $def_language
-	 * *                           optional, ISO 639-1 language code (e.g. 'en', 'de', see lng-folder for supported languages),
-	 * *                           default is system-default language
+	 *                             optional, ISO 639-1 language code (e.g. 'en', 'de', see lng-folder for supported languages),
+	 *                             default is system-default language
 	 * @param bool $gui_access
 	 *                             optional, allow login via webui, if false ONLY the login via webui is disallowed; default true
 	 * @param bool $api_allowed
 	 *                             optional, default is true if system setting api.enabled is true, else false
+	 * @param bool $shell_allowed
+	 *                             optional, default is true if system setting system.allow_customer_shell is true, else false
 	 * @param int $gender
 	 *                             optional, 0 = no-gender, 1 = male, 2 = female
 	 * @param string $custom_notes
@@ -1128,6 +1137,7 @@ class Customers extends ApiCommand implements ResourceEntity
 			$def_language = $this->getParam('def_language', true, $result['def_language']);
 			$gui_access = $this->getBoolParam('gui_access', true, $result['gui_access']);
 			$api_allowed = $this->getBoolParam('api_allowed', true, $result['api_allowed']);
+			$shell_allowed = $this->getBoolParam('shell_allowed', true, $result['shell_allowed']);
 			$gender = (int)$this->getParam('gender', true, $result['gender']);
 			$custom_notes = $this->getParam('custom_notes', true, $result['custom_notes']);
 			$custom_notes_show = $this->getBoolParam('custom_notes_show', true, $result['custom_notes_show']);
@@ -1367,7 +1377,7 @@ class Customers extends ApiCommand implements ResourceEntity
 				]);
 
 				// enable/disable global mysql-user (loginname)
-				$current_allowed_mysqlserver =  isset($result['allowed_mysqlserver']) && !empty($result['allowed_mysqlserver']) ? json_decode($result['allowed_mysqlserver'], true) : [];
+				$current_allowed_mysqlserver = isset($result['allowed_mysqlserver']) && !empty($result['allowed_mysqlserver']) ? json_decode($result['allowed_mysqlserver'], true) : [];
 				foreach ($current_allowed_mysqlserver as $dbserver) {
 					// require privileged access for target db-server
 					Database::needRoot(true, $dbserver, true);
@@ -1498,6 +1508,7 @@ class Customers extends ApiCommand implements ResourceEntity
 				'custom_notes_show' => $custom_notes_show,
 				'gui_access' => $gui_access,
 				'api_allowed' => $api_allowed,
+				'shell_allowed' => $shell_allowed,
 				'allowed_mysqlserver' => empty($allowed_mysqlserver) ? "" : json_encode($allowed_mysqlserver)
 			];
 			$upd_data += $admin_upd_data;
@@ -1542,6 +1553,7 @@ class Customers extends ApiCommand implements ResourceEntity
 				`custom_notes_show` = :custom_notes_show,
 				`gui_access` = :gui_access,
 				`api_allowed` = :api_allowed,
+				`shell_allowed` = :shell_allowed,
 				`allowed_mysqlserver` = :allowed_mysqlserver";
 			$upd_query .= $admin_upd_query;
 		}
@@ -1647,6 +1659,13 @@ class Customers extends ApiCommand implements ResourceEntity
 			Database::query($admin_update_query);
 		}
 
+		// shell allowance has changed
+		if ($result['shell_allowed'] == '1' && $shell_allowed == '0') {
+			// update all users with a valid shell to have /bin/false (disable shell)
+			$ftp_upd_stmt = Database::prepare("UPDATE `" . TABLE_FTP_USERS . "` SET `shell` = '/bin/false' WHERE `customerid` = :cid");
+			Database::pexecute($ftp_upd_stmt, ['cid' => (int)$result['customerid']]);
+		}
+
 		$this->logger()->logAction($this->isAdmin() ? FroxlorLogger::ADM_ACTION : FroxlorLogger::USR_ACTION, LOG_NOTICE, "[API] edited user '" . $result['loginname'] . "'");
 
 		/*
@@ -1699,7 +1718,7 @@ class Customers extends ApiCommand implements ResourceEntity
 			$id = $result['customerid'];
 
 			// remove global mysql-user (loginname)
-			$current_allowed_mysqlserver =  isset($result['allowed_mysqlserver']) && !empty($result['allowed_mysqlserver']) ? json_decode($result['allowed_mysqlserver'], true) : [];
+			$current_allowed_mysqlserver = isset($result['allowed_mysqlserver']) && !empty($result['allowed_mysqlserver']) ? json_decode($result['allowed_mysqlserver'], true) : [];
 			foreach ($current_allowed_mysqlserver as $dbserver) {
 				// require privileged access for target db-server
 				Database::needRoot(true, $dbserver, false);
