@@ -218,7 +218,7 @@ final class ConfigServices extends CliCommand
 		$_daemons_config['distro'] = $io->choice('Choose distribution', $valid_dists, $os_default);
 
 		// go through all services and let user check whether to include it or not
-		if (empty($_daemons_config['distro']) || !file_exists($config_dir . '/' . $_daemons_config['distro']. ".xml")) {
+		if (empty($_daemons_config['distro']) || !file_exists($config_dir . '/' . $_daemons_config['distro'] . ".xml")) {
 			$output->writeln('<error>Empty or non-existing distribution given.</>');
 			return self::INVALID;
 		}
@@ -359,13 +359,16 @@ final class ConfigServices extends CliCommand
 		if (!empty($decoded_config)) {
 
 			$config_dir = Froxlor::getInstallDir() . 'lib/configfiles/';
-			if (empty($decoded_config['distro']) || !file_exists($config_dir . '/' . $decoded_config['distro']. ".xml")) {
+			if (empty($decoded_config['distro']) || !file_exists($config_dir . '/' . $decoded_config['distro'] . ".xml")) {
 				$output->writeln('<error>Empty or non-existing distribution given. Please login with an admin, go to "System -> Configuration" and select your correct distribution in the top-right corner or specify valid distribution name for "distro" parameter.</>');
 				return self::INVALID;
 			}
-			$configfiles = new ConfigParser($config_dir . '/' . $decoded_config['distro']. ".xml");
+			$configfiles = new ConfigParser($config_dir . '/' . $decoded_config['distro'] . ".xml");
 			$services = $configfiles->getServices();
 			$replace_arr = $this->getReplacerArray();
+			$clean_replace_arr = array_map(function ($v) {
+				return escapeshellarg((string)($v ?? ''));
+			}, $replace_arr);
 
 			// be sure the fallback certificate specified in the settings exists
 			$certFile = Settings::Get('system.ssl_cert_file');
@@ -400,13 +403,13 @@ final class ConfigServices extends CliCommand
 							case "install":
 								$output->writeln("Installing required packages");
 								$result = null;
-								passthru(strtr($action['content'], $replace_arr), $result);
+								passthru(strtr($action['content'], $clean_replace_arr), $result);
 								if (strlen($result) > 1) {
 									echo $result;
 								}
 								break;
 							case "command":
-								exec(strtr($action['content'], $replace_arr));
+								exec(strtr($action['content'], $clean_replace_arr));
 								break;
 							case "file":
 								if (array_key_exists('content', $action)) {
