@@ -1,8 +1,8 @@
 <?php
 
 /**
- * This file is part of the Froxlor project.
- * Copyright (c) 2010 the Froxlor Team (see authors).
+ * This file is part of the froxlor project.
+ * Copyright (c) 2010 the froxlor Team (see authors).
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License
@@ -19,7 +19,7 @@
  * https://files.froxlor.org/misc/COPYING.txt
  *
  * @copyright  the authors
- * @author     Froxlor team <team@froxlor.org>
+ * @author     froxlor team <team@froxlor.org>
  * @license    https://files.froxlor.org/misc/COPYING.txt GPLv2
  */
 
@@ -34,7 +34,6 @@ return [
 		'sections' => [
 			'section_a' => [
 				'title' => lng('domains.domainsettings'),
-				'image' => 'icons/domain_add.png',
 				'fields' => [
 					'domain' => [
 						'label' => 'Domain',
@@ -90,7 +89,6 @@ return [
 			],
 			'section_e' => [
 				'title' => lng('admin.mailserversettings'),
-				'image' => 'icons/domain_add.png',
 				'fields' => [
 					'isemaildomain' => [
 						'label' => lng('admin.emaildomain'),
@@ -121,7 +119,6 @@ return [
 			],
 			'section_b' => [
 				'title' => lng('admin.webserversettings'),
-				'image' => 'icons/domain_add.png',
 				'fields' => [
 					'documentroot' => [
 						'label' => 'DocumentRoot',
@@ -185,7 +182,6 @@ return [
 			],
 			'section_bssl' => [
 				'title' => lng('admin.webserversettings_ssl'),
-				'image' => 'icons/domain_add.png',
 				'visible' => Settings::Get('system.use_ssl') == '1',
 				'fields' => [
 					'sslenabled' => [
@@ -227,12 +223,20 @@ return [
 						'checked' => false
 					],
 					'http2' => [
-						'visible' => !empty($ssl_ipsandports) && Settings::Get('system.webserver') != 'lighttpd' && Settings::Get('system.http2_support') == '1',
+						'visible' => !empty($ssl_ipsandports) && Settings::Get('system.http2_support') == '1',
 						'label' => lng('admin.domain_http2.title'),
 						'desc' => lng('admin.domain_http2.description'),
 						'type' => 'checkbox',
 						'value' => '1',
-						'checked' => false
+						'checked' => true
+					],
+					'http3' => [
+						'visible' => !empty($ssl_ipsandports) && Settings::Get('system.webserver') == 'nginx' && Settings::Get('system.http3_support') == '1',
+						'label' => lng('admin.domain_http3.title'),
+						'desc' => lng('admin.domain_http3.description') . lng('admin.domain_http3.nginx_version_warning'),
+						'type' => 'checkbox',
+						'value' => '1',
+						'checked' => true
 					],
 					'override_tls' => [
 						'visible' => !empty($ssl_ipsandports) && $userinfo['change_serversettings'] == '1',
@@ -242,13 +246,11 @@ return [
 						'checked' => false
 					],
 					'ssl_protocols' => [
-						'visible' => !empty($ssl_ipsandports) && $userinfo['change_serversettings'] == '1' && Settings::Get('system.webserver') != 'lighttpd',
+						'visible' => !empty($ssl_ipsandports) && $userinfo['change_serversettings'] == '1',
 						'label' => lng('serversettings.ssl.ssl_protocols.title'),
 						'desc' => lng('serversettings.ssl.ssl_protocols.description').lng('admin.domain_override_tls_addinfo'),
 						'type' => 'checkbox',
-						'value' => [
-							'TLSv1.2'
-						],
+						'value' => explode(",", Settings::Get('system.ssl_protocols') ?? 'TLSv1.2'),
 						'values' => [
 							[
 								'value' => 'TLSv1',
@@ -324,7 +326,7 @@ return [
 						'checked' => false
 					],
 					'ocsp_stapling' => [
-						'visible' => !empty($ssl_ipsandports) && Settings::Get('system.webserver') != 'lighttpd',
+						'visible' => !empty($ssl_ipsandports),
 						'label' => lng('admin.domain_ocsp_stapling.title'),
 						'desc' => lng('admin.domain_ocsp_stapling.description') . (Settings::Get('system.webserver') == 'nginx' ? lng('admin.domain_ocsp_stapling.nginx_version_warning') : ""),
 						'type' => 'checkbox',
@@ -339,7 +341,7 @@ return [
 						'checked' => false
 					],
 					'sessiontickets' => [
-						'visible' => !empty($ssl_ipsandports) && Settings::Get('system.webserver') != 'lighttpd' && Settings::Get('system.sessionticketsenabled' != '1'),
+						'visible' => !empty($ssl_ipsandports) && Settings::Get('system.sessionticketsenabled' != '1'),
 						'label' => lng('admin.domain_sessiontickets'),
 						'type' => 'checkbox',
 						'value' => '1',
@@ -349,7 +351,6 @@ return [
 			],
 			'section_c' => [
 				'title' => lng('admin.phpserversettings'),
-				'image' => 'icons/domain_add.png',
 				'visible' => $userinfo['change_serversettings'] == '1' || $userinfo['caneditphpsettings'] == '1',
 				'fields' => [
 					'openbasedir' => [
@@ -391,7 +392,6 @@ return [
 			],
 			'section_d' => [
 				'title' => lng('admin.nameserversettings'),
-				'image' => 'icons/domain_add.png',
 				'visible' => Settings::Get('system.bind_enable') == '1' && $userinfo['change_serversettings'] == '1',
 				'fields' => [
 					'isbinddomain' => [
