@@ -4,12 +4,24 @@ export default function () {
 		 * updatecheck
 		 */
 		if (document.getElementById('updatecheck')) {
+			runCheck();
+		}
+
+		function runCheck(force = 0)
+		{
 			$.ajax({
-				url: "lib/ajax.php?action=updatecheck&theme=" + window.$theme,
+				url: "lib/ajax.php?action=updatecheck&theme=" + window.$theme + "&force=" + force,
 				type: "GET",
 				success: function (data) {
 					$("#updatecheck").html(data);
-					new bootstrap.Popover(document.getElementById('ucheck'));
+					const po = new bootstrap.Popover(document.getElementById('ucheck'));
+					const myPopoverTrigger = document.getElementById('ucheck')
+					myPopoverTrigger.addEventListener('shown.bs.popover', () => {
+						$('#forceUpdateCheck').on('click', function () {
+							runCheck(1);
+							po.hide();
+						});
+					})
 				},
 				error: function (request, status, error) {
 					console.log(request, status, error)
